@@ -1,3 +1,6 @@
+from .specializations import *
+from .specializations.database_query import *
+from .gpt_classes import search_in_conversation
 from .gpt_classes.api_selection.ApiBuilder import ApiManager
 from .gpt_classes.model_selection.ModelBuilder import ModelManager
 from .gpt_classes.prompt_selection.PromptBuilder import PromptManager
@@ -5,6 +8,6 @@ from .gpt_classes.response_selection.ResponseBuilder import ResponseManager
 from .gpt_classes.instruction_selection.InstructionBuilder import InstructionManager
 from .gpt_classes.nogui_selection.nogui_query import nogui_setup_module
 from .gpt_classes.nogui_selection.general_query import make_general_query
-from .specializations import *
-from .specializations.database_query import *
 from .abstract_ai_gui import abstract_ai_gui
+from .ai_call_package import make_ai_api_call
+from .specializations import initialize_clipit
