@@ -144,7 +144,7 @@ def get_created(data=None,file_path=None):
     return make_list(get_any_value(data, 'created') or None)[0]
 def get_response(data=None,file_path=None):
     data = get_data(data=data,file_path=file_path)
-    return make_list(get_any_value(data,'response') or None)[0]
+    return make_list(get_any_value(data,'response') or data)[0]
 def get_choices(data=None,file_path=None):
     data = get_data(data=data,file_path=file_path)
     return make_list(get_any_value(data,'choices') or None)[0]
@@ -156,24 +156,29 @@ def get_file_path(data=None,file_path=None):
     return make_list(get_any_value(data,'file_path') or None)[0]
 def get_response_content(data=None,file_path=None):
     data = get_data(data=data,file_path=file_path)
-    return get_response(data=data,file_path=file_path) or get_any_value(safe_json_loads(data),'response')
+    response = get_response(data=data,file_path=file_path)
+    if not response:
+        response = get_any_value(safe_json_loads(data),'response')
+    return response
 def get_api_response(data=None,file_path=None):
+    data = get_data(data=data,file_path=file_path)
     data = get_response_content(data=data,file_path=file_path)
     response_data = make_list(get_any_value(data,'api_response') or None)[0]
-    if response_data == None and "'api_response':" in data or '"api_response":' in data:
+    if data and response_data == None and "'api_response':" in data or '"api_response":' in data:
         response_data = data.split("'api_response':")[-1].split('"api_response":')[-1]
         for key in ['notation','additional_responses','suggestions','generate_title','prompt_as_previous']:
             response_data= response_data.split(f"'{key}':")[0].split(f'"{key}":')[0]
     return response_data
 def get_updated_response_content(data=None,file_path=None):
     response_content = get_response_content(data=data,file_path=file_path)
-    content = get_content(response_content)
+    content = get_content(response_content) or {}
     new_js = {
         "generate_title":get_title(data=data,file_path=file_path),
         "created":get_created(data=data,file_path=file_path),
         "model":get_model(data=data,file_path=file_path),
         "file_path":get_file_path(data=data,file_path=file_path)}
-    content.update(new_js)
+    if isinstance(content,dict):
+        content.update(new_js)
     return content
 def get_files_list(directory=None,files_list=None):
     files_list = files_list or directory
@@ -193,8 +198,8 @@ def get_cronological_file_list(directory=None,files_list=None):
     for file_path in content_data_list:
         curr_created = int(get_created(file_path=file_path))
         if curr_created<prev_created:
-            input('out of o order')
-        prev_created = curr_created
+
+            prev_created = curr_created
     return content_data_list
 def get_ordered_data(directory=None,files_list=None):
     chron_files_list = get_cronological_file_list(directory=directory,files_list=files_list)
@@ -268,4 +273,3 @@ class ResponseFileCollator:
     
         return data
 
-
